Simple test
------------

Ensure your device works with this simple test. When working, will play the first
sound stored on the DFPlayer Pro.

.. literalinclude:: ../examples/df1201s_simpletest.py
    :caption: examples/df1201s_simpletest.py
    :linenos:

More Features
--------------

Explore more features of the DFPlayer Pro, including volume adjustment, play modes,
and play status.

.. literalInclude:: ../examples/df1201s_morefeatures.py
    :caption: examples/df1201s_morefeatures.py
    :linenos:
